@@ -59,18 +59,20 @@ class CommandCopy(base.CommandBase):
               help="global timeout for the transfer operation")
     @base.arg('-K', "--checksum", type=str, default=None,
               help='checksum algorithm to use, or algorithm:value')
-    @base.arg("--copy-mode", type=str, default='', choices=['pull', 'push', 'streamed',''],
-              help='copy mode. N.B. supported only for HTTP/DAV to HTTP/DAV transfers, if not specified the pull mode will be executed first with fallbacks to other modes in case of errors')
     @base.arg("--checksum-mode", type=str, default='both', choices=['source', 'target', 'both'],
               help='checksum validation mode')
     @base.arg('--from-file', type=str, default=None,
               help="read sources from a file")
+    @base.arg("--copy-mode", type=str, default='', choices=['pull', 'push', 'streamed'],
+              help='copy mode. N.B. supported only for HTTP/DAV to HTTP/DAV transfers, if not specified the pull mode will be executed first with fallbacks to other modes in case of errors')
     @base.arg('--just-copy', action='store_true',
               help="just do the copy and skip any preparation (i.e. checksum, overwrite, etc.)")
     @base.arg('--no-delegation', action='store_true',
               help="disable TPC with proxy delegation")
     @base.arg('--evict', action='store_true',
               help="evict source file from disk buffer when the transfer is finished")
+    @base.arg('--scitag', type=int, default=None,
+              help="SciTag transfer flow identifier (number in [65-65535] range) (available only for HTTP-TPC)")
     @base.arg('-r', '--recursive', action='store_true',
               help="copy directories recursively")
     @base.arg('--abort-on-failure', action='store_true',
@@ -85,7 +87,7 @@ class CommandCopy(base.CommandBase):
         Copy a file or set of files
         """
         if self.params.from_file and self.params.src:
-            sys.stderr.write("Could not combine --from-file with a source in the positional arguments\n")
+            sys.stderr.write("Cannot combine '--from-file' with a source in the positional arguments\n")
             return 1
 
         copy_jobs = list()
@@ -222,20 +224,22 @@ class CommandCopy(base.CommandBase):
         if self.params.just_copy:
             t.strict_copy = True
         if self.params.no_delegation:
-            if hasattr(t, 'proxy_delegation'): # available since gfal2-python 1.10.0
-                t.proxy_delegation = False
-            else:
-                sys.stderr.write("[warn] '--no-delegation' flag requires gfal2-python >= 1.10.0\n")
-        if self.params.evict:
+            t.proxy_delegation = False
+        if self.params.evict:  # available since gfal2-python 1.12.0
             if hasattr(t, 'evict'):
                 t.evict = True
             else:
-                sys.stderr.write("[warn] '--evict' flag requires gfal2-python >= 1.12.0\n")
+                sys.stderr.write("[warn] '--evict' flag requires python{}-gfal2 >= 1.12.0\n".format(sys.version_info.major))
+        if self.params.scitag is not None:
+            if hasattr(t, 'scitag'):  # available since gfal2-python 1.12.2
+                t.scitag = self.params.scitag
+            else:
+                sys.stderr.write("[warn] '--scitag' flag requires python{}-gfal2 >= 1.12.2\n".format(sys.version_info.major))
         if self.params.checksum:
             chk_args = self.params.checksum.split(':')
             if len(chk_args) == 1:
                 chk_args.append('')
-            if hasattr(t, 'set_checksum'): # available since gfal-python 1.9.0
+            if hasattr(t, 'set_checksum'):  # available since gfal2-python 1.9.0
                 mode = dict(
                         source=gfal2.checksum_mode.source,
                         target=gfal2.checksum_mode.target,
